@@ -39,7 +39,7 @@ pub enum Side {
     Sell,
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Clone, Copy, Serialize, Deserialize)]
 /// Defines the possible order errors that can occur when submitting a new order
 pub enum OrderError {
     /// Maximum number of active orders reached
@@ -54,7 +54,7 @@ pub enum OrderError {
     NotEnoughAvailableBalance,
 }
 
-#[derive(Debug, Clone, Serialize, Deserialize)]
+#[derive(Debug, Clone, Copy, Serialize, Deserialize)]
 /// Defines the available order types
 pub enum OrderType {
     /// aggressive market order
@@ -65,7 +65,7 @@ pub enum OrderType {
     StopMarket,
 }
 
-#[derive(Debug, Clone, Serialize, Deserialize)]
+#[derive(Debug, Clone, Copy, Serialize, Deserialize)]
 /// Defines the two fee types for different types of orders
 pub enum FeeType {
     /// The fee for passive maker orders such as limit order
@@ -74,7 +74,7 @@ pub enum FeeType {
     Taker,
 }
 
-#[derive(Debug, Clone, Serialize, Deserialize)]
+#[derive(Debug, Clone, Copy, Serialize, Deserialize)]
 /// Define the Exchange configuration
 pub struct Config {
     /// The maker fee as a fraction. e.g.: 2.5 basis points rebate -> -0.00025
